@@ -30,7 +30,7 @@ from soco_cli.utils import (
     local_speaker_list,
     save_readline_history,
     set_interactive,
-    set_suspend_sigterm,
+    set_suspend_sighandling,
     speaker_cache,
     version,
 )
@@ -56,6 +56,10 @@ ACTIONS_TO_EXEC = [
     "wait_stopped_for_not_pause",
     "wsfnp",
     "wait_end_track",
+    "play_file",
+    "play_local_file",
+    "play_m3u",
+    "play_local_m3u",
 ]
 
 
@@ -808,13 +812,13 @@ def _exec(command_line):
     # Convert command list to a unified command line
     command_line = " ".join(command_line)
 
-    set_suspend_sigterm(suspend=True)
+    set_suspend_sighandling(suspend=True)
     try:
         logging.info("Running command: '{}'".format(command_line))
         subprocess.run(command_line, shell=True)
     except Exception as e:
         print(e)
-    set_suspend_sigterm(suspend=False)
+    set_suspend_sighandling(suspend=False)
 
 
 def _exec_action(speaker_ip, action, args):
@@ -836,6 +840,3 @@ def _exec_action(speaker_ip, action, args):
 
     logging.info("Running '{}' in a subprocess. Terminate using CTRL-C.".format(action))
     _exec(command_line)
-
-    if action in ["track_follow", "tf", "track_follow_compact", "tfc"]:
-        print()
